@@ -1,6 +1,6 @@
 #' Plot method for multicollinearity checks
 #'
-#' The \code{plot()} method for the \code{performance::check_collinearity()} function.
+#' The `plot()` method for the `performance::check_collinearity()` function.
 #'
 #' @inheritParams data_plot
 #' @inheritParams plot.see_check_normality
@@ -15,7 +15,10 @@
 #' plot(result)
 #' @importFrom rlang .data
 #' @export
-plot.see_check_collinearity <- function(x, data = NULL, colors = c("#3aaf85", "#1b6ca8", "#cd201f"), ...) {
+plot.see_check_collinearity <- function(x,
+                                        data = NULL,
+                                        colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
+                                        ...) {
   if (is.null(data)) {
     dat <- .compact_list(.retrieve_data(x))
   } else {
