@@ -1,6 +1,6 @@
 #' Plot method for (conditional) equivalence testing
 #'
-#' The \code{plot()} method for the \code{bayestestR::equivalence_test()} function.
+#' The `plot()` method for the `bayestestR::equivalence_test()` function.
 #'
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
@@ -13,9 +13,6 @@
 #' m <- aov(mpg ~ factor(am) * factor(cyl), data = mtcars)
 #' result <- eta_squared(m)
 #' plot(result)
-#' @importFrom stats setNames
-#' @importFrom insight clean_parameters
-#' @importFrom ggridges geom_density_ridges2
 #' @export
 plot.see_equivalence_test <- function(x,
                                       rope_color = "#0171D3",
@@ -46,8 +43,8 @@ plot.see_equivalence_test <- function(x,
     return(x)
   }
 
-  if (inherits(model, "emmGrid") && !requireNamespace("emmeans", quietly = TRUE)) {
-    stop("Package 'emmeans' required for this function to work. Please install it.", call. = FALSE)
+  if (inherits(model, "emmGrid")) {
+    insight::check_if_installed("emmeans")
   }
 
   # if we have intercept-only models, keep at least the intercept
@@ -397,41 +394,40 @@ plot.see_equivalence_test_lm <- function(x,
   p <- ggplot(
     x,
     aes_string(
-      x = "Parameter",
-      y = "Estimate",
-      ymin = "CI_low",
-      ymax = "CI_high",
+      y = "Parameter",
+      x = "Estimate",
+      xmin = "CI_low",
+      xmax = "CI_high",
       colour = "ROPE_Equivalence"
     )
   ) +
     annotate(
       "rect",
-      ymin = .rope[1],
-      ymax = .rope[2],
-      xmin = 0,
-      xmax = Inf,
+      xmin = .rope[1],
+      xmax = .rope[2],
+      ymin = 0,
+      ymax = Inf,
       fill = rope_color,
       alpha = (rope_alpha / 3)
     ) +
-    geom_hline(
-      yintercept = .rope,
+    geom_vline(
+      xintercept = .rope,
       linetype = "dashed",
       colour = rope_color,
       size = .8,
       alpha = rope.line.alpha
     ) +
-    geom_hline(
-      yintercept = 0,
+    geom_vline(
+      xintercept = 0,
       colour = rope_color,
       size = .8,
       alpha = rope.line.alpha
     ) +
     geom_pointrange(size = size_point) +
     scale_colour_manual(values = fill.color) +
-    labs(x = x.title, y = NULL, colour = legend.title) +
+    labs(y = x.title, x = NULL, colour = legend.title) +
     theme(legend.position = "bottom") +
-    coord_flip() +
-    scale_x_discrete()
+    scale_y_discrete()
 
   if ("Group" %in% colnames(x)) {
     p <- p + facet_wrap(~Group, scales = "free", ncol = n_columns)
