@@ -1,7 +1,5 @@
 #' @export
-plot.visualisation_recipe <- function(x, ...) {
-  insight::check_if_installed("ggplot2")
-
+plot.see_visualisation_recipe <- function(x, ...) {
   ggplot2::ggplot(data = attributes(x)$data) +
     geoms_from_list(x, ...)
 }
